import os
from django.conf import settings
from django.template import Context, Template
from django.test.testcases import SimpleTestCase

from svg.exceptions import SVGNotFound


class SVGTemplateTagTest(SimpleTestCase):

    def test_should_render_svg(self):
        svg_file = open(os.path.join(settings.BASE_DIR,
                                     'static',
                                     'svg',
                                     'django.svg')).read()
        template = Template("{% load svg %}{% svg 'django' %}")

        self.assertEqual(svg_file, template.render(Context()))

    def test_when_given_invalid_file_it_should_fail_silently(self):
        template = Template("{% load svg %}{% svg 'thisdoesntexist' %}")

        self.assertEqual('', template.render(Context()))

    def test_when_debug_it_should_raise_an_error(self):
        template = Template("{% load svg %}{% svg 'thisdoesntexist' %}")

        with self.settings(DEBUG=True):
            with self.assertRaises(SVGNotFound):
                template.render(Context())



from __future__ import absolute_import
import logging
import os

from django import template
from django.conf import settings
from django.contrib.staticfiles import finders
from django.utils.safestring import mark_safe

from svg.exceptions import SVGNotFound

logger = logging.getLogger(__name__)
register = template.Library()


@register.simple_tag
def svg(filename):
    path = finders.find(os.path.join('svg', '%s.svg' % filename), all=True)

    if not path:
        message = "SVG 'svg/%s.svg' not found" % filename

        if settings.DEBUG:
            raise SVGNotFound(message)
        else:
            logger.warning(message)
            return ''

    if isinstance(path, (list, tuple)):
        path = path[0]

    with open(path) as svg_file:
        svg = mark_safe(svg_file.read())

    return svg



from os import chdir
from os.path import abspath, dirname, join, normpath
from setuptools import find_packages, setup

with open(join(dirname(__file__), 'README.rst')) as readme:
    README = readme.read()


# allow setup.py to be run from any path
chdir(normpath(abspath(dirname(__file__))))

import svg  # noqa

setup(
    name='django-inline-svg',
    version=svg.__version__,
    packages=find_packages(exclude=['test*']),
    include_package_data=True,
    license=svg.__license__,
    description=svg.__doc__,
    long_description=README,
    url='https://github.com/mixxorz/django-svg',
    author='Mitchel Cabuloy',
    author_email='mixxorz@gmail.com',
    maintainer='Mitchel Cabuloy',
    maintainer_email='mixxorz@gmail.com',
    install_requires=[
        'Django>=1.8'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Plugins',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    test_suite='tests',
)
